/*
 * Copyright (C) 2009 SHARP Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.co.sharp.android.SampleIrdaIrss;

import android.app.Activity;
import android.content.ContentResolver;
import android.database.Cursor;
import android.net.Uri;
import android.provider.MediaStore;

/**
 * データベースからコンテンツの状態を取得するクラスである。
 * データベースの情報はMediaStoreを使用して取得する。
 * MediaStoreはAndroid標準の機能である。
 */
public class SampleFilePickerGetContentStatus {

    /**
     * コンストラクタ
     */
    public SampleFilePickerGetContentStatus() {

    }

    /**
     * データベースからコンテンツ情報を取得するメソッドである。
     * @param uri URI
     * @param act 呼び元のアクティビティ
     */
    public SampleFilePickerStatusModel getContentOne(Uri uri, Activity act) {
        /* ContentResolver取得 */
        ContentResolver mResolver = act.getContentResolver();
        /* SampleFilePickerStatusModel作成 */
        SampleFilePickerStatusModel statusModel  = new SampleFilePickerStatusModel();;

        final String[] columns = {
                MediaStore.MediaColumns.DISPLAY_NAME,
                MediaStore.MediaColumns.TITLE,
                MediaStore.MediaColumns.DATA,
                MediaStore.MediaColumns.MIME_TYPE,
                MediaStore.MediaColumns.SIZE,
        };

        /* cursor作成 */
        Cursor cursor = mResolver.query(uri, columns, null, null, null);
        if (cursor != null && cursor.getCount() > 0) {
            /* cursorを先頭へ移動 */
            cursor.moveToFirst();
            /* columns indexを設定 */
            int indexFileNameFull = cursor.getColumnIndex(MediaStore.MediaColumns.DISPLAY_NAME);
            int mindexFileName = cursor.getColumnIndex(MediaStore.MediaColumns.TITLE);
            int indexData = cursor.getColumnIndex(MediaStore.MediaColumns.DATA);
            int indexMimeType = cursor.getColumnIndex(MediaStore.MediaColumns.MIME_TYPE);
            int indexFileSize = cursor.getColumnIndex(MediaStore.MediaColumns.SIZE);
            /* フルファイル名取得 */
            statusModel.setFileNameFull(cursor.getString(indexFileNameFull));
            /* ファイル名取得 */
            statusModel.setFileName(cursor.getString(mindexFileName));
            /* ファイルパス取得 */
            statusModel.setFilePath(cursor.getString(indexData));
            /* MIMEタイプ取得 */
            statusModel.setMimeType(cursor.getString(indexMimeType));
            /* サイズ取得 */
            statusModel.setFileSize(cursor.getLong(indexFileSize));
            /* URI取得 */
            statusModel.setUri(uri);
            /* cursorを閉じる */
            cursor.close();
        }

        return statusModel;

    }

}